Models
******

.. contents::
    :depth: 2
    :local:

Fields
======

.. autoclass:: dj_kaos_utils.models.TwoPlacesDecimalField
    :show-inheritance:

.. autoclass:: dj_kaos_utils.models.MoneyField
   :show-inheritance:

.. autoclass:: dj_kaos_utils.models.CaseInsensitiveFieldMixin
   :show-inheritance:

.. autoclass:: dj_kaos_utils.models.ToLowerCaseFieldMixin
   :show-inheritance:

.. autoclass:: dj_kaos_utils.models.LowerCaseCharField
   :show-inheritance:

QuerySets
=========

Refer to :doc:`querysets`


Mixins
=======

.. autoclass:: dj_kaos_utils.models.HasAutoFields
   :members: set_auto_fields
   :show-inheritance:

.. autoclass:: dj_kaos_utils.models.HasInitials
   :members: initials
   :show-inheritance:

.. autoclass:: dj_kaos_utils.models.HasWarnings
   :members: get_warnings
   :show-inheritance:


Admin
=====

.. autoclass:: dj_kaos_utils.models.admin.HasWarningsAdmin
   :show-inheritance:
